@@ -1,7 +1,8 @@
 import re
 import json
 import requests
-from grafana_backup.commons import log_response
+import sys
+from grafana_backup.commons import log_response, to_python2_and_3_compatible_string
 
 
 def health_check(grafana_url, http_get_headers, verify_ssl, client_cert, debug):
@@ -55,7 +56,12 @@ def paging_feature_check(grafana_url, http_get_headers, verify_ssl, client_cert,
     def get_first_dashboard_by_page(page):
         (status, content) = search_dashboard(page, 1, grafana_url, http_get_headers, verify_ssl, client_cert, debug)
         if status == 200 and len(content):
-            dashboard_values = sorted(content[0].items(), key=lambda kv: str(kv[1]))
+            if sys.version_info[0] > 2:
+                content[0] = {k: to_python2_and_3_compatible_string(v) for k,v in content[0].items()}
+                dashboard_values = sorted(content[0].items(), key=lambda kv: str(kv[1]))
+            else:
+                content[0] = {k: to_python2_and_3_compatible_string(unicode(v)) for k,v in content[0].iteritems()}
+                dashboard_values = sorted(content[0].iteritems(), key=lambda kv: str(kv[1]))
             return True, dashboard_values
         else:
             if len(content):
@@ -244,23 +250,32 @@ def get_folder_permissions(uid, grafana_url, http_get_headers, verify_ssl, clien
 
 def update_folder_permissions(payload, grafana_url, http_post_headers, verify_ssl, client_cert, debug):
     items = json.dumps({'items': payload})
-    return send_grafana_post('{0}/api/folders/{1}/permissions'.format(grafana_url,payload[0]['uid']), items, http_post_headers, verify_ssl, client_cert,
+    return send_grafana_post('{0}/api/folders/{1}/permissions'.format(grafana_url, payload[0]['uid']), items, http_post_headers, verify_ssl, client_cert,
                              debug)
 
 
-def get_folder_id_from_old_folder_url(folder_url, grafana_url, http_post_headers, verify_ssl, client_cert, debug):
-    if folder_url != "":
-        # Get folder uid
-        matches = re.search('dashboards\/[A-Za-z0-9]{1}\/(.*)\/.*', folder_url)
-        uid = matches.group(1)
+def get_folder_id(dashboard, grafana_url, http_post_headers, verify_ssl, client_cert, debug):
+    folder_uid = ""
+    try:
+        folder_uid = dashboard['meta']['folderUid']
+    except (KeyError):
+        matches = re.search('dashboards\/f\/(.*)\/.*', dashboard['meta']['folderUrl'])
+        folder_uid = matches.group(1)
 
-        response = get_folder(uid, grafana_url, http_post_headers, verify_ssl, client_cert, debug)
+    if (folder_uid != ""):
+        print("debug: quering with uid {}".format(folder_uid))
+        response = get_folder(folder_uid, grafana_url, http_post_headers, verify_ssl, client_cert, debug)
         if isinstance(response[1], dict):
             folder_data = response[1]
         else:
             folder_data = json.loads(response[1])
-        return folder_data['id']
-    return 0
+
+        try:
+            return folder_data['id']
+        except (KeyError):
+            return 0
+    else:
+        return 0
 
 
 def create_folder(payload, grafana_url, http_post_headers, verify_ssl, client_cert, debug):
